==> ah-formbuilder-1.0.61.tgz: package/es/utils/checkboxs/CheckboxGroup.js <==
import React from 'react';
import { makeStyles } from '@material-ui/core/styles';
import FormGroup from '@material-ui/core/FormGroup';
import FormControlLabel from '@material-ui/core/FormControlLabel';
import Checkbox from '@material-ui/core/Checkbox';
import FormControl from "@material-ui/core/FormControl";
import FormLabel from "@material-ui/core/FormLabel";
import FormHelperText from "@material-ui/core/FormHelperText";
import _ from 'lodash';
export default function CheckboxGroup(props) {
  var row = props.row,
      options = props.options,
      value = props.value,
      handleChange = props.handleChange,
      label = props.label,
      error = props.error,
      required = props.required,
      helperText = props.helperText,
      disabled = props.disabled;
  var labelProp = props.labelProp ? props.labelProp : 'label';
  var valueProp = props.valueProp ? props.valueProp : 'value';

  var handleValueChange = function handleValueChange(val) {
    var newValue = _.cloneDeep(value);

    if (newValue.includes(val)) {
      newValue.splice(value.indexOf(val), 1);
    } else {
      newValue.push(val);
    }

    handleChange({
      target: {
        value: newValue
      }
    });
  };

  return /*#__PURE__*/React.createElement(FormControl, {
    required: required,
    error: error,
    component: "fieldset",
    disabled: disabled
  }, /*#__PURE__*/React.createElement(FormLabel, {
    component: "label"
  }, label), /*#__PURE__*/React.createElement(FormGroup, {
    row: row
  }, options.map(function (option) {
    return /*#__PURE__*/React.createElement(FormControlLabel, {
      key: 'option-' + option[valueProp],
      control: /*#__PURE__*/React.createElement(Checkbox, {
        checked: value.includes(option[valueProp]),
        onChange: function onChange(e) {
          return handleValueChange(option[valueProp]);
        },
        value: option[valueProp]
      }),
      label: option[labelProp]
    });
  })), /*#__PURE__*/React.createElement(FormHelperText, null, error ? error : helperText ? helperText : ''));
}

==> ah-formbuilder-1.0.92.tgz: package/es/utils/checkboxs/CheckboxGroup.js <==
var _jsxFileName = "/home/zaman/Documents/GitLab/bayt/formbuilder/src/utils/checkboxs/CheckboxGroup.js";
import React from 'react';
import { makeStyles } from '@material-ui/core/styles';
import FormGroup from '@material-ui/core/FormGroup';
import FormControlLabel from '@material-ui/core/FormControlLabel';
import Checkbox from '@material-ui/core/Checkbox';
import FormControl from "@material-ui/core/FormControl";
import FormLabel from "@material-ui/core/FormLabel";
import FormHelperText from "@material-ui/core/FormHelperText";
import _ from 'lodash';
export default function CheckboxGroup(props) {
  var _this = this;

  var row = props.row,
      options = props.options,
      value = props.value,
      handleChange = props.handleChange,
      label = props.label,
      error = props.error,
      required = props.required,
      helperText = props.helperText,
      disabled = props.disabled;
  var labelProp = props.labelProp ? props.labelProp : 'label';
  var valueProp = props.valueProp ? props.valueProp : 'value';

  var handleValueChange = function handleValueChange(val) {
    var newValue = _.cloneDeep(value);

    if (newValue.includes(val)) {
      newValue.splice(value.indexOf(val), 1);
    } else {
      newValue.push(val);
    }

    handleChange({
      target: {
        value: newValue
      }
    });
  };

  return /*#__PURE__*/React.createElement(FormControl, {
    required: required,
    error: error,
    component: "fieldset",
    disabled: disabled,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 27,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(FormLabel, {
    component: "label",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 28,
      columnNumber: 7
    }
  }, label), /*#__PURE__*/React.createElement(FormGroup, {
    row: row,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 29,
      columnNumber: 7
    }
  }, options.map(function (option) {
    return /*#__PURE__*/React.createElement(FormControlLabel, {
      key: 'option-' + option[valueProp],
      control: /*#__PURE__*/React.createElement(Checkbox, {
        checked: value.includes(option[valueProp]),
        onChange: function onChange(e) {
          return handleValueChange(option[valueProp]);
        },
        value: option[valueProp],
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 33,
          columnNumber: 15
        }
      }),
      label: option[labelProp],
      __self: _this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 31,
        columnNumber: 11
      }
    });
  })), /*#__PURE__*/React.createElement(FormHelperText, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 39,
      columnNumber: 7
    }
  }, error ? error : helperText ? helperText : ''));
}
